@@ -16,7 +16,7 @@ my %class = (
     'drawer'      => 'Bio::Phylo::Treedrawer',
     'treedrawer'  => 'Bio::Phylo::Treedrawer',    
     'project'     => 'Bio::Phylo::Project',
-    'dictionary'  => 'Bio::Phylo::Dictionary',
+#    'dictionary'  => 'Bio::Phylo::Dictionary',
     'annotation'  => 'Bio::Phylo::Annotation',
     'set'         => 'Bio::Phylo::Set',
     'generator'   => 'Bio::Phylo::Generator',
